==> autoscaling-1.60.0-sources.jar: software/amazon/awscdk/services/autoscaling/Ec2HealthCheckOptions.java <==
package software.amazon.awscdk.services.autoscaling;

/**
 * EC2 Heath check options.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:23.648Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.autoscaling.$Module.class, fqn = "@aws-cdk/aws-autoscaling.Ec2HealthCheckOptions")
@software.amazon.jsii.Jsii.Proxy(Ec2HealthCheckOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface Ec2HealthCheckOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Specified the time Auto Scaling waits before checking the health status of an EC2 instance that has come into service.
     * <p>
     * Default: Duration.seconds(0)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.Duration getGrace() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link Ec2HealthCheckOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Ec2HealthCheckOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<Ec2HealthCheckOptions> {
        private software.amazon.awscdk.core.Duration grace;

        /**
         * Sets the value of {@link Ec2HealthCheckOptions#getGrace}
         * @param grace Specified the time Auto Scaling waits before checking the health status of an EC2 instance that has come into service.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder grace(software.amazon.awscdk.core.Duration grace) {
            this.grace = grace;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Ec2HealthCheckOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public Ec2HealthCheckOptions build() {
            return new Jsii$Proxy(grace);
        }
    }

    /**
     * An implementation for {@link Ec2HealthCheckOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Ec2HealthCheckOptions {
        private final software.amazon.awscdk.core.Duration grace;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.grace = this.jsiiGet("grace", software.amazon.awscdk.core.Duration.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.core.Duration grace) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.grace = grace;
        }

        @Override
        public software.amazon.awscdk.core.Duration getGrace() {
            return this.grace;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getGrace() != null) {
                data.set("grace", om.valueToTree(this.getGrace()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-autoscaling.Ec2HealthCheckOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Ec2HealthCheckOptions.Jsii$Proxy that = (Ec2HealthCheckOptions.Jsii$Proxy) o;

            return this.grace != null ? this.grace.equals(that.grace) : that.grace == null;
        }

        @Override
        public int hashCode() {
            int result = this.grace != null ? this.grace.hashCode() : 0;
            return result;
        }
    }
}

==> autoscaling-1.93.0-sources.jar: software/amazon/awscdk/services/autoscaling/Ec2HealthCheckOptions.java <==
package software.amazon.awscdk.services.autoscaling;

/**
 * EC2 Heath check options.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:47:04.989Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.autoscaling.$Module.class, fqn = "@aws-cdk/aws-autoscaling.Ec2HealthCheckOptions")
@software.amazon.jsii.Jsii.Proxy(Ec2HealthCheckOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface Ec2HealthCheckOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Specified the time Auto Scaling waits before checking the health status of an EC2 instance that has come into service.
     * <p>
     * Default: Duration.seconds(0)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.Duration getGrace() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link Ec2HealthCheckOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Ec2HealthCheckOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<Ec2HealthCheckOptions> {
        private software.amazon.awscdk.core.Duration grace;

        /**
         * Sets the value of {@link Ec2HealthCheckOptions#getGrace}
         * @param grace Specified the time Auto Scaling waits before checking the health status of an EC2 instance that has come into service.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder grace(software.amazon.awscdk.core.Duration grace) {
            this.grace = grace;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Ec2HealthCheckOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public Ec2HealthCheckOptions build() {
            return new Jsii$Proxy(grace);
        }
    }

    /**
     * An implementation for {@link Ec2HealthCheckOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Ec2HealthCheckOptions {
        private final software.amazon.awscdk.core.Duration grace;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.grace = software.amazon.jsii.Kernel.get(this, "grace", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.Duration.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.core.Duration grace) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.grace = grace;
        }

        @Override
        public final software.amazon.awscdk.core.Duration getGrace() {
            return this.grace;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getGrace() != null) {
                data.set("grace", om.valueToTree(this.getGrace()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-autoscaling.Ec2HealthCheckOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Ec2HealthCheckOptions.Jsii$Proxy that = (Ec2HealthCheckOptions.Jsii$Proxy) o;

            return this.grace != null ? this.grace.equals(that.grace) : that.grace == null;
        }

        @Override
        public final int hashCode() {
            int result = this.grace != null ? this.grace.hashCode() : 0;
            return result;
        }
    }
}
